package com.cweb.controller;

import com.alibaba.fastjson.JSONObject;
import com.hai.common.exception.ErrorCode;
import com.hai.common.exception.ErrorHelp;
import com.hai.common.exception.SysCode;
import com.hai.common.security.*;
import com.hai.common.utils.ResponseMsgUtil;
import com.hai.model.ResponseData;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Objects;

@Controller
@RequestMapping(value = "/login")
@Api(value = "登录")
public class LoginController {

    private static Logger log = LoggerFactory.getLogger(LoginController.class);

    @Resource
    private UserCenter userCenter;

    @RequestMapping(value="/userLogin",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "用户登录 {'phone':'','password':'','code':'','type':''}")
    public ResponseData userLogin(@RequestBody String reqBody, HttpServletRequest request, HttpServletResponse response) {
        try {


          /*  UserInfoModel userInfoModel = new UserInfoModel();
            String aesStr = AESEncodeUtil.aesEncrypt(customer.getId().toString());
            SessionObject so = new SessionObject(aesStr, 1,userInfoModel);
            userCenter.save(request, response, so);*/
            return ResponseMsgUtil.success(null);
        } catch (Exception e) {
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/logout",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "登出")
    public ResponseData logout(HttpServletRequest request, HttpServletResponse response){
        try {
            userCenter.remove(request, response);
            return ResponseMsgUtil.success("退出成功");

        } catch (Exception e) {
            log.error("login error!",e);
            return ResponseMsgUtil.exception(e);
        }

    }

    @RequestMapping(value="/checkVerifyCode",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "校验验证码 （{'phone':'','code':''}）")
    public ResponseData checkVerifyCode(@RequestBody String reqBody){
        try {
            if(StringUtils.isBlank(reqBody)) {
                log.error("login error!","参数错误");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
            JSONObject jsonObject = JSONObject.parseObject(reqBody);
            String phone = jsonObject.getString("phone");
            String code = jsonObject.getString("code");
            if(StringUtils.isBlank(phone) || StringUtils.isBlank(code)) {
                log.error("login error!","参数错误");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }

            VerifyCode verifyCode = VerifyCodeStorage.getDate(phone);
            if (verifyCode == null) {
                return ResponseMsgUtil.success(false);
            }

            // 校验验证码
            if (Objects.equals(String.valueOf(verifyCode.getObject()),code)) {
                // 清除记录，验证码只能验证一次
                //2020-08-06暂不做清除处理
                //VerifyCodeStorage.remove(phone);
                return ResponseMsgUtil.success(true);
            } else {
                return ResponseMsgUtil.success(false);
            }
        } catch (Exception e) {
            log.error("login error!",e);
            return ResponseMsgUtil.exception(e);
        }

    }

    @RequestMapping(value="/forgetPassword",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "忘记密码 ({'phone':'','code':'','password':'','sign':''})")
    public ResponseData forgetPassword(@RequestBody String reqBody) {
        try {

            JSONObject jsonObject = JSONObject.parseObject(reqBody);

            String phone = jsonObject.getString("phone");	    //用户电话
            String code = jsonObject.getString("code");         // 验证码
            String password = jsonObject.getString("password");//新密码

            if(StringUtils.isBlank(phone) || StringUtils.isBlank(code) ||
                    StringUtils.isBlank(password)) {
                log.error("LoginController --> forgetPassword() error!","参数错误");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }

            VerifyCode verifyCode = VerifyCodeStorage.getDate(phone);
            if (verifyCode == null) {
                log.error("LoginController --> forgetPassword() error!","验证码错误");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.SMS_CODE_ERROR, "");
            }

            // 校验验证码
            if (!Objects.equals(String.valueOf(verifyCode.getObject()),code)) {
                log.error("LoginController --> forgetPassword() error!","验证码错误");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.SMS_CODE_ERROR, "");
            }

            return ResponseMsgUtil.success("密码设置成功");
        } catch (Exception e) {
            log.error("LoginController --> forgetPassword() error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

}
